# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHSR_METADATA = Metadata(
    id="eb82e2176f14f70334dc8bcaf770b81e214106e0.boutiques",
    name="mri_synthsr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthsrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthsr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_synthsr(
    input_: str,
    output: str,
    ct: bool = False,
    disable_sharpening: bool = False,
    disable_flipping: bool = False,
    lowfield: bool = False,
    v1: bool = False,
    threads: float | None = None,
    cpu: bool = False,
    model: str | None = None,
    runner: Runner | None = None,
) -> MriSynthsrOutputs:
    """
    Implementation of SynthSR that generates a synthetic 1mm MP-RAGE from a scan of
    any contrast and resolution.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_: Image(s) to super-resolve. Can be a path to an image or to a\
            folder.
        output: Output(s), i.e., synthetic 1mm MP-RAGE(s). Must be a folder if\
            input is a folder.
        ct: Use this flag for CT scans in Hounsfield scale, it clips\
            intensities to [0,80].
        disable_sharpening: Use this flag to disable unsharp masking.
        disable_flipping: Use this flag to disable flipping augmentation at\
            test time.
        lowfield: Use model for low-field scans (e.g., acquired with\
            Hyperfine's Swoop scanner).
        v1: Use version 1 model from July 2021.
        threads: Number of cores to be used. Default is 1.
        cpu: Enforce running with CPU rather than GPU.
        model: Use a different model file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthsrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHSR_METADATA)
    cargs = []
    cargs.append("mri_synthsr")
    cargs.append(input_)
    cargs.append(output)
    if ct:
        cargs.append("--ct")
    if disable_sharpening:
        cargs.append("--disable_sharpening")
    if disable_flipping:
        cargs.append("--disable_flipping")
    if lowfield:
        cargs.append("--lowfield")
    if v1:
        cargs.append("--v1")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if cpu:
        cargs.append("--cpu")
    if model is not None:
        cargs.extend([
            "--model",
            model
        ])
    ret = MriSynthsrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHSR_METADATA",
    "MriSynthsrOutputs",
    "mri_synthsr",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

JKGCATRAIN_METADATA = Metadata(
    id="9a38b64221a25b990a7d0af6bcb52cf21f4a0120.boutiques",
    name="jkgcatrain",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class JkgcatrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `jkgcatrain(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def jkgcatrain(
    gca_directory: str,
    iteration_number: float | None = 2,
    num_threads: float | None = None,
    no_submit: bool = False,
    mail_flag: bool = False,
    runner: Runner | None = None,
) -> JkgcatrainOutputs:
    """
    Jackknife training of GCA using existing output from gcatrain.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gca_directory: Output directory from gcatrain.
        iteration_number: Iteration number (usually 2).
        num_threads: Number of threads to use.
        no_submit: Run serially, do not use pbsubmit.
        mail_flag: Mail to user when jobs are pbsubmitted or finished.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `JkgcatrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(JKGCATRAIN_METADATA)
    cargs = []
    cargs.append("jkgcatrain")
    cargs.extend([
        "--g",
        gca_directory
    ])
    if iteration_number is not None:
        cargs.extend([
            "--iter",
            str(iteration_number)
        ])
    if num_threads is not None:
        cargs.extend([
            "--nthreads",
            str(num_threads)
        ])
    if no_submit:
        cargs.append("--no-submit")
    if mail_flag:
        cargs.append("--pb-m")
    ret = JkgcatrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "JKGCATRAIN_METADATA",
    "JkgcatrainOutputs",
    "jkgcatrain",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3DMASKDUMP_METADATA = Metadata(
    id="9cb4c849a9357c37ec67fbe234f23f59f3a3a158.boutiques",
    name="3dmaskdump",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dmaskdumpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3dmaskdump(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output ASCII file with voxel values"""


def v_3dmaskdump(
    input_files: list[InputPathType],
    mask_dataset: InputPathType | None = None,
    mask_range: list[str] | None = None,
    output_index: bool = False,
    output_noijk: bool = False,
    output_xyz: bool = False,
    output_filename: str | None = None,
    calc_mask_opts: str | None = None,
    xbox_coords: str | None = None,
    dbox_coords: str | None = None,
    nbox_coords: str | None = None,
    ibox_coords: str | None = None,
    xball_coords: str | None = None,
    dball_coords: str | None = None,
    nball_coords: str | None = None,
    nozero_output: bool = False,
    random_voxels: float | None = None,
    random_seed: float | None = None,
    output_niml: str | None = None,
    quiet_mode: bool = False,
    runner: Runner | None = None,
) -> V3dmaskdumpOutputs:
    """
    Outputs voxel values from AFNI datasets satisfying mask criteria to an ASCII
    file.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: Input datasets to dump voxel values.
        mask_dataset: Use the dataset as a mask. Only voxels with nonzero\
            values in the mask will be printed from the input dataset.
        mask_range: Further restrict the voxels from mask dataset to those mask\
            values between 'a' and 'b' (inclusive).
        output_index: Write out the dataset index values.
        output_noijk: Do not write out the i,j,k values.
        output_xyz: Write the x,y,z coordinates from the first input dataset at\
            the start of each output line.
        output_filename: Write output to specified file.
        calc_mask_opts: Execute options enclosed as a 3dcalc-like program to\
            produce a mask from the resulting 3D brick.
        xbox_coords: Put a 'mask' at dataset coordinates 'x y z' mm.
        dbox_coords: Put a 'mask' at RAI/DICOM coordinates of 'x y z' mm.
        nbox_coords: Put a 'mask' at LPI/SPM coordinates of 'x y z' mm.
        ibox_coords: Put a 'mask' at voxel indexes 'i j k'.
        xball_coords: Put a ball (sphere) mask at dataset coordinates (x,y,z)\
            with radius r.
        dball_coords: Put a ball (sphere) mask at RAI/DICOM coordinates (x,y,z)\
            with radius r.
        nball_coords: Put a ball (sphere) mask at LPI/SPM coordinates (x,y,z)\
            with radius r.
        nozero_output: Skip output of any voxel where all the data values are\
            zero.
        random_voxels: Keep only N_RAND randomly selected voxels from what\
            would have been the output.
        random_seed: Seed the random number generator with SEED.
        output_niml: Output data in the XML/NIML format compatible with input\
            back to AFNI via the READ_NIML_FILE command.
        quiet_mode: Do not print progress messages to stderr.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dmaskdumpOutputs`).
    """
    if mask_range is not None and (len(mask_range) != 2): 
        raise ValueError(f"Length of 'mask_range' must be 2 but was {len(mask_range)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3DMASKDUMP_METADATA)
    cargs = []
    cargs.append("3dmaskdump")
    cargs.extend([execution.input_file(f) for f in input_files])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    if mask_range is not None:
        cargs.extend([
            "-mrange",
            *mask_range
        ])
    if output_index:
        cargs.append("-index")
    if output_noijk:
        cargs.append("-noijk")
    if output_xyz:
        cargs.append("-xyz")
    if output_filename is not None:
        cargs.extend([
            "-o",
            output_filename
        ])
    if calc_mask_opts is not None:
        cargs.extend([
            "-cmask",
            calc_mask_opts
        ])
    if xbox_coords is not None:
        cargs.extend([
            "-xbox",
            xbox_coords
        ])
    if dbox_coords is not None:
        cargs.extend([
            "-dbox",
            dbox_coords
        ])
    if nbox_coords is not None:
        cargs.extend([
            "-nbox",
            nbox_coords
        ])
    if ibox_coords is not None:
        cargs.extend([
            "-ibox",
            ibox_coords
        ])
    if xball_coords is not None:
        cargs.extend([
            "-xball",
            xball_coords
        ])
    if dball_coords is not None:
        cargs.extend([
            "-dball",
            dball_coords
        ])
    if nball_coords is not None:
        cargs.extend([
            "-nball",
            nball_coords
        ])
    if nozero_output:
        cargs.append("-nozero")
    if random_voxels is not None:
        cargs.extend([
            "-n_rand",
            str(random_voxels)
        ])
    if random_seed is not None:
        cargs.extend([
            "-n_randseed",
            str(random_seed)
        ])
    if output_niml is not None:
        cargs.extend([
            "-niml",
            output_niml
        ])
    if quiet_mode:
        cargs.append("-quiet")
    ret = V3dmaskdumpOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_filename) if (output_filename is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dmaskdumpOutputs",
    "V_3DMASKDUMP_METADATA",
    "v_3dmaskdump",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MESH_SUBDIVIDE_METADATA = Metadata(
    id="fb137b14730056953d8eae8a55716f7ac7551282.boutiques",
    name="mris_mesh_subdivide",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMeshSubdivideOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_mesh_subdivide(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    subdivided_surface: OutputPathType
    """The subdivided mesh surface output file"""


def mris_mesh_subdivide(
    input_surface: InputPathType,
    output_surface: str,
    subdivision_method: typing.Literal["butterfly", "loop", "linear"] | None = None,
    iterations: float | None = None,
    runner: Runner | None = None,
) -> MrisMeshSubdivideOutputs:
    """
    This program will subdivide a triangular mesh surface.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Name of input surface file.
        output_surface: Name for output surface file (outputs to same directory\
            as input if path not provided).
        subdivision_method: Subdivision method: options are 'butterfly'\
            (default), 'loop', or 'linear'.
        iterations: Number of subdivision iterations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMeshSubdivideOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MESH_SUBDIVIDE_METADATA)
    cargs = []
    cargs.append("mris_mesh_subdivide")
    cargs.extend([
        "--surf",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "--out",
        output_surface
    ])
    if subdivision_method is not None:
        cargs.extend([
            "--method",
            subdivision_method
        ])
    if iterations is not None:
        cargs.extend([
            "--iter",
            str(iterations)
        ])
    ret = MrisMeshSubdivideOutputs(
        root=execution.output_file("."),
        subdivided_surface=execution.output_file(output_surface),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MESH_SUBDIVIDE_METADATA",
    "MrisMeshSubdivideOutputs",
    "mris_mesh_subdivide",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURF_TO_SURF_METADATA = Metadata(
    id="a2c971cd7bb0ee914e8be7cd7e5159482c16cc13.boutiques",
    name="SurfToSurf",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class SurfToSurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surf_to_surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file in 1D format"""


def surf_to_surf(
    input_surface_1: InputPathType,
    input_surface_2: InputPathType,
    surface_volume: InputPathType | None = None,
    prefix: str | None = None,
    output_params: str | None = None,
    node_indices: InputPathType | None = None,
    proj_dir: InputPathType | None = None,
    data: InputPathType | None = None,
    node_debug: float | None = None,
    debug_level: float | None = None,
    make_consistent: bool = False,
    dset: InputPathType | None = None,
    mapfile: InputPathType | None = None,
    runner: Runner | None = None,
) -> SurfToSurfOutputs:
    """
    Interpolate data from one surface to another.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_surface_1: First input surface file (S1).
        input_surface_2: Second input surface file (S2).
        surface_volume: Specify the surface volume (SV1).
        prefix: Specify prefix for the output file.
        output_params: List of mapping parameters to include in output.
        node_indices: 1D file containing node indices of S1 to consider.
        proj_dir: 1D file containing projection directions.
        data: 1D file containing data to be interpolated.
        node_debug: Node index for debugging purposes.
        debug_level: Debugging level.
        make_consistent: Force a consistency check and correct triangle\
            orientation.
        dset: Dataset file for data interpolation; mutually exclusive with\
            -data.
        mapfile: File containing mapping parameters between surfaces S2 and S1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfToSurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURF_TO_SURF_METADATA)
    cargs = []
    cargs.append("SurfToSurf")
    cargs.append(execution.input_file(input_surface_1))
    cargs.append(execution.input_file(input_surface_2))
    if surface_volume is not None:
        cargs.extend([
            "-sv",
            execution.input_file(surface_volume)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if output_params is not None:
        cargs.extend([
            "-output_params",
            output_params
        ])
    if node_indices is not None:
        cargs.extend([
            "-node_indices",
            execution.input_file(node_indices)
        ])
    if proj_dir is not None:
        cargs.extend([
            "-proj_dir",
            execution.input_file(proj_dir)
        ])
    if data is not None:
        cargs.extend([
            "-data",
            execution.input_file(data)
        ])
    if node_debug is not None:
        cargs.extend([
            "-node_debug",
            str(node_debug)
        ])
    if debug_level is not None:
        cargs.extend([
            "-debug",
            str(debug_level)
        ])
    if make_consistent:
        cargs.append("-make_consistent")
    if dset is not None:
        cargs.extend([
            "-dset",
            execution.input_file(dset)
        ])
    if mapfile is not None:
        cargs.extend([
            "-mapfile",
            execution.input_file(mapfile)
        ])
    ret = SurfToSurfOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".1D") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURF_TO_SURF_METADATA",
    "SurfToSurfOutputs",
    "surf_to_surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SSWARPER_METADATA = Metadata(
    id="197ce8d754dd8af8616a9982ec614230700e19aa.boutiques",
    name="@SSwarper",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSswarperOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__sswarper(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    anat_do: OutputPathType
    """Deobliqued version of original dataset"""
    anat_u: OutputPathType
    """Intensity uniform-ized original dataset"""
    anat_ua: OutputPathType
    """Anisotropically smoothed version of the uniformized dataset"""
    anat_uac: OutputPathType
    """Ceiling-capped version of the anisotropically smoothed dataset"""
    anat_s: OutputPathType
    """First pass skull-stripped original dataset"""
    anat_ss: OutputPathType
    """Second pass skull-stripped original dataset"""
    anat_qq: OutputPathType
    """Skull-stripped dataset nonlinearly warped to the base template space"""
    anat_qq_affine: OutputPathType
    """Affine matrix to transform original dataset to base template space"""
    anat_qq_warp: OutputPathType
    """Incremental warp from affine transformation to nonlinearly aligned
    dataset"""
    am_snapshot: OutputPathType
    """3x3 snapshot image of the nonlinearly warped dataset with edges from the
    base template overlaid"""
    ma_snapshot: OutputPathType
    """Similar to AM_snapshot, but with roles of the template and anatomical
    dataset reversed"""
    qc_anat_qq: OutputPathType
    """3 rows of 8 slices snapshot image for checking alignment"""
    qc_anat_ss: OutputPathType
    """Snapshot image to check skullstripping in original space"""
    init_overlap_qc: OutputPathType
    """Montage to check initial overlap of source and base datasets"""


def v__sswarper(
    input_file: InputPathType,
    base_template: InputPathType,
    subject_id: str,
    output_dir: str | None = None,
    min_patch_size: float | None = None,
    no_lite: bool = False,
    skip_warp: bool = False,
    unifize_off: bool = False,
    init_skullstr_off: bool = False,
    extra_qc_off: bool = False,
    jump_to_extra_qc: bool = False,
    cost_nl_init: str | None = None,
    cost_nl_final: str | None = None,
    deoblique: bool = False,
    deoblique_refitly: bool = False,
    warp_scale: float | None = None,
    ssopt_flag: str | None = None,
    aniso_off: bool = False,
    ceil_off: bool = False,
    tmp_name_nice: bool = False,
    echo: bool = False,
    verbose: bool = False,
    noclean: bool = False,
    runner: Runner | None = None,
) -> VSswarperOutputs:
    """
    Dual purposes for processing a given subject's anatomical volume: skull-strip
    the brain and calculate the warp to a reference template/standard space.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: An anatomical dataset, not skull-stripped, with about 1 mm\
            resolution.
        base_template: A base template dataset with similar contrast to the\
            input dataset.
        subject_id: Name code for output datasets (e.g., 'sub007').
        output_dir: Output directory for all files from this program.
        min_patch_size: Minimum patch size on final 3dQwarp.
        no_lite: Do not use the '-lite' option with 3dQwarp.
        skip_warp: Do not compute past the output of anatSS.<subid>.nii.
        unifize_off: Do not start with a 3dUnifize command.
        init_skullstr_off: Do not preprocess with a 3dSkullstrip command.
        extra_qc_off: Do not make extra QC images.
        jump_to_extra_qc: Just make the two QC*jpg images from a previous run.
        cost_nl_init: Specify cost function for initial nonlinear (3dQwarp)\
            part of alignment.
        cost_nl_final: Specify cost function for final nonlinear (3dQwarp)\
            parts of alignment.
        deoblique: Apply obliquity information to deoblique the input volume.
        deoblique_refitly: Purge obliquity information to deoblique the input\
            volume.
        warp_scale: Control flexibility of warps in 3dQwarp.
        ssopt_flag: Append a string of options for 3dSkullStrip.
        aniso_off: Do not preprocess with a 3danisosmooth command.
        ceil_off: Turn off capping on values after anisosmoothing.
        tmp_name_nice: Use nicer, non-random intermediate file prefix for\
            temporary files.
        echo: Run the script with 'set echo' for extra verbosity in the\
            terminal output.
        verbose: Apply the '-verb' option to 3dQwarp for verbose progress\
            information.
        noclean: Do not delete the 'junk' files at the end of computations.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSswarperOutputs`).
    """
    if warp_scale is not None and not (0.1 <= warp_scale <= 1.0): 
        raise ValueError(f"'warp_scale' must be between 0.1 <= x <= 1.0 but was {warp_scale}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SSWARPER_METADATA)
    cargs = []
    cargs.append("@SSwarper")
    cargs.extend([
        "-input",
        execution.input_file(input_file)
    ])
    cargs.extend([
        "-base",
        execution.input_file(base_template)
    ])
    cargs.extend([
        "-subid",
        subject_id
    ])
    if output_dir is not None:
        cargs.extend([
            "-odir",
            output_dir
        ])
    if min_patch_size is not None:
        cargs.extend([
            "-minp",
            str(min_patch_size)
        ])
    if no_lite:
        cargs.append("-nolite")
    if skip_warp:
        cargs.append("-skipwarp")
    if unifize_off:
        cargs.append("-unifize_off")
    if init_skullstr_off:
        cargs.append("-init_skullstr_off")
    if extra_qc_off:
        cargs.append("-extra_qc_off")
    if jump_to_extra_qc:
        cargs.append("-jump_to_extra_qc")
    if cost_nl_init is not None:
        cargs.extend([
            "-cost_nl_init",
            cost_nl_init
        ])
    if cost_nl_final is not None:
        cargs.extend([
            "-cost_nl_final",
            cost_nl_final
        ])
    if deoblique:
        cargs.append("-deoblique")
    if deoblique_refitly:
        cargs.append("-deoblique_refitly")
    if warp_scale is not None:
        cargs.extend([
            "-warpscale",
            str(warp_scale)
        ])
    if ssopt_flag is not None:
        cargs.extend([
            "-SSopt",
            ssopt_flag
        ])
    if aniso_off:
        cargs.append("-aniso_off")
    if ceil_off:
        cargs.append("-ceil_off")
    if tmp_name_nice:
        cargs.append("-tmp_name_nice")
    if echo:
        cargs.append("-echo")
    if verbose:
        cargs.append("-verb")
    if noclean:
        cargs.append("-noclean")
    ret = VSswarperOutputs(
        root=execution.output_file("."),
        anat_do=execution.output_file("anatDO." + subject_id + ".nii"),
        anat_u=execution.output_file("anatU." + subject_id + ".nii"),
        anat_ua=execution.output_file("anatUA." + subject_id + ".nii"),
        anat_uac=execution.output_file("anatUAC." + subject_id + ".nii"),
        anat_s=execution.output_file("anatS." + subject_id + ".nii"),
        anat_ss=execution.output_file("anatSS." + subject_id + ".nii"),
        anat_qq=execution.output_file("anatQQ." + subject_id + ".nii"),
        anat_qq_affine=execution.output_file("anatQQ." + subject_id + ".aff12.1D"),
        anat_qq_warp=execution.output_file("anatQQ." + subject_id + "_WARP.nii"),
        am_snapshot=execution.output_file("AM" + subject_id + ".jpg"),
        ma_snapshot=execution.output_file("MA" + subject_id + ".jpg"),
        qc_anat_qq=execution.output_file("QC_anatQQ." + subject_id + ".jpg"),
        qc_anat_ss=execution.output_file("QC_anatSS." + subject_id + ".jpg"),
        init_overlap_qc=execution.output_file("init_qc_00_overlap_uinp_obase.jpg"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSswarperOutputs",
    "V__SSWARPER_METADATA",
    "v__sswarper",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ADJUNCT_SUMA_FS_ROI_INFO_METADATA = Metadata(
    id="779dea93198c9c27ce2d88ef43623927b9130d07.boutiques",
    name="adjunct_suma_fs_roi_info",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AdjunctSumaFsRoiInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `adjunct_suma_fs_roi_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    rois_2000_ft: OutputPathType
    """Info for the '2000' parcellation."""
    rois_2009_ft: OutputPathType
    """Info for the '2009' parcellation."""
    segs_2000_ft: OutputPathType
    """Info for the '2000' parcellation brain mask and tissue/segmentations."""
    segs_2009_ft: OutputPathType
    """Info for the '2009' parcellation brain mask and tissue/segmentations."""


def adjunct_suma_fs_roi_info(
    subject_id: str,
    suma_directory: str,
    help_: bool = False,
    hview: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> AdjunctSumaFsRoiInfoOutputs:
    """
    Script for making ROI stats for the SUMA/ directory created by
    @SUMA_Make_Spec_FS after running FreeSurfer's recon-all.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        subject_id: Subject ID.
        suma_directory: SUMA directory output by AFNI's @SUMA_Make_Spec_FS.
        help_: Show help.
        hview: Show help in text editor.
        version: Show version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AdjunctSumaFsRoiInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ADJUNCT_SUMA_FS_ROI_INFO_METADATA)
    cargs = []
    cargs.append("adjunct_suma_fs_roi_info")
    cargs.extend([
        "-sid",
        subject_id
    ])
    cargs.extend([
        "-suma_dir",
        suma_directory
    ])
    if help_:
        cargs.append("-help")
    if hview:
        cargs.append("-hview")
    if version:
        cargs.append("-ver")
    ret = AdjunctSumaFsRoiInfoOutputs(
        root=execution.output_file("."),
        rois_2000_ft=execution.output_file("stats_fs_rois_2000_FT.1D"),
        rois_2009_ft=execution.output_file("stats_fs_rois_2009_FT.1D"),
        segs_2000_ft=execution.output_file("stats_fs_segs_2000_FT.1D"),
        segs_2009_ft=execution.output_file("stats_fs_segs_2009_FT.1D"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ADJUNCT_SUMA_FS_ROI_INFO_METADATA",
    "AdjunctSumaFsRoiInfoOutputs",
    "adjunct_suma_fs_roi_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

LABEL_GEOMETRY_MEASURES_METADATA = Metadata(
    id="e7ce3202e62bc39e7b15a1562ae20a5cef322440.boutiques",
    name="LabelGeometryMeasures",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class LabelGeometryMeasuresOutputs(typing.NamedTuple):
    """
    Output object returned when calling `label_geometry_measures(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_csv: OutputPathType | None
    """The CSV file containing the geometry measures."""


def label_geometry_measures(
    image_dimension: int,
    label_image: InputPathType,
    intensity_image: str | None = None,
    csv_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> LabelGeometryMeasuresOutputs:
    """
    This tool computes various geometry measures on a label image, optionally using
    an intensity image, and outputs the results to a CSV file.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the input images (e.g., 2 for\
            2D, 3 for 3D).
        label_image: The label image on which geometry measures are computed.
        intensity_image: An optional intensity image for computing\
            intensity-weighted measures. Use "none" or "na" if not provided.
        csv_file: The output file where the geometry measures are written in\
            CSV format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `LabelGeometryMeasuresOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(LABEL_GEOMETRY_MEASURES_METADATA)
    cargs = []
    cargs.append("LabelGeometryMeasures")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(label_image))
    if intensity_image is not None:
        cargs.append(intensity_image)
    if csv_file is not None:
        cargs.append(execution.input_file(csv_file))
    ret = LabelGeometryMeasuresOutputs(
        root=execution.output_file("."),
        output_csv=execution.output_file(pathlib.Path(csv_file).name) if (csv_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "LABEL_GEOMETRY_MEASURES_METADATA",
    "LabelGeometryMeasuresOutputs",
    "label_geometry_measures",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GIFTI_LABEL_TO_ROI_METADATA = Metadata(
    id="252be09cb9f5099d7e1cc317ddf28a5cc85d2ab6.boutiques",
    name="gifti-label-to-roi",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class GiftiLabelToRoiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gifti_label_to_roi(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


def gifti_label_to_roi(
    label_in: InputPathType,
    metric_out: str,
    opt_name_label_name: str | None = None,
    opt_key_label_key: int | None = None,
    opt_map_map: str | None = None,
    runner: Runner | None = None,
) -> GiftiLabelToRoiOutputs:
    """
    Make a gifti label into an roi metric.
    
    For each map in <label-in>, a map is created in <metric-out> where all
    locations labeled with <label-name> or with a key of <label-key> are given a
    value of 1, and all other locations are given 0. Exactly one of -name and
    -key must be specified. Specify -map to use only one map from <label-in>.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input gifti label file.
        metric_out: the output metric file.
        opt_name_label_name: select label by name: the label name that you want\
            an roi of.
        opt_key_label_key: select label by key: the label key that you want an\
            roi of.
        opt_map_map: select a single label map to use: the map number or name.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelToRoiOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_LABEL_TO_ROI_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-label-to-roi")
    cargs.append(execution.input_file(label_in))
    cargs.append(metric_out)
    if opt_name_label_name is not None:
        cargs.extend([
            "-name",
            opt_name_label_name
        ])
    if opt_key_label_key is not None:
        cargs.extend([
            "-key",
            str(opt_key_label_key)
        ])
    if opt_map_map is not None:
        cargs.extend([
            "-map",
            opt_map_map
        ])
    ret = GiftiLabelToRoiOutputs(
        root=execution.output_file("."),
        metric_out=execution.output_file(metric_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GIFTI_LABEL_TO_ROI_METADATA",
    "GiftiLabelToRoiOutputs",
    "gifti_label_to_roi",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_NUDGE_METADATA = Metadata(
    id="6f298ed7d045a2ce709015d0cecce0980607d9d6.boutiques",
    name="mris_nudge",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisNudgeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_nudge(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType
    """Output surface file after nudging"""


def mris_nudge(
    input_surface: InputPathType,
    input_volume: InputPathType,
    vertex: int,
    target_val: float,
    nbhd: int,
    runner: Runner | None = None,
) -> MrisNudgeOutputs:
    """
    A tool to nudge vertex positions on a surface using a volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file for nudging.
        input_volume: Input volume file.
        vertex: Vertex to nudge.
        target_val: Target value for nudging.
        nbhd: Neighborhood size for nudge operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisNudgeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_NUDGE_METADATA)
    cargs = []
    cargs.append("mris_nudge")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(input_volume))
    cargs.append(str(vertex))
    cargs.append(str(target_val))
    cargs.append(str(nbhd))
    cargs.append("[OUTPUT_SURF]")
    ret = MrisNudgeOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file("[OUTPUT_SURF]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_NUDGE_METADATA",
    "MrisNudgeOutputs",
    "mris_nudge",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_HAUSDORFF_DIST_METADATA = Metadata(
    id="3bfc7962f48ea4f5a174be4b80f4251d364d4270.boutiques",
    name="mri_hausdorff_dist",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriHausdorffDistOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_hausdorff_dist(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_text: OutputPathType
    """Output text file containing the results of Hausdorff distance
    calculation"""


def mri_hausdorff_dist(
    vol1: InputPathType,
    vol2: InputPathType,
    output_text_file: InputPathType,
    threshold: float | None = None,
    input_file_flag: bool = False,
    blur_sigma: float | None = None,
    max_flag: bool = False,
    label_index: float | None = None,
    runner: Runner | None = None,
) -> MriHausdorffDistOutputs:
    """
    Tool for computing the mean or max of the minimum distances between point sets
    in 3D volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vol1: First input volume.
        vol2: Second input volume.
        output_text_file: Output text file.
        threshold: Binarize input volumes with given threshold.
        input_file_flag: Read volumes from an input file (first argument is the\
            input filename).
        blur_sigma: Blur the input image with Gaussian of specified sigma.
        max_flag: Compute the maximum of the minimum distances instead of the\
            mean.
        label_index: Use specified label index as the target label.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriHausdorffDistOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_HAUSDORFF_DIST_METADATA)
    cargs = []
    cargs.append("mri_hausdorff_dist")
    cargs.append(execution.input_file(vol1))
    cargs.append(execution.input_file(vol2))
    cargs.append(execution.input_file(output_text_file))
    cargs.append("[BINARIZE_FLAG]")
    if threshold is not None:
        cargs.extend([
            "-b",
            str(threshold)
        ])
    if input_file_flag:
        cargs.append("-F")
    if blur_sigma is not None:
        cargs.extend([
            "-g",
            str(blur_sigma)
        ])
    if max_flag:
        cargs.append("-max")
    if label_index is not None:
        cargs.extend([
            "-l",
            str(label_index)
        ])
    ret = MriHausdorffDistOutputs(
        root=execution.output_file("."),
        output_text=execution.output_file(pathlib.Path(output_text_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_HAUSDORFF_DIST_METADATA",
    "MriHausdorffDistOutputs",
    "mri_hausdorff_dist",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RSFC_METADATA = Metadata(
    id="b5c2a121f1ca24f0166e661caec651b36aec44bd.boutiques",
    name="3dRSFC",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRsfcOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_rsfc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filtered_time_series: OutputPathType
    """Filtered time series output"""
    un_bandpassed_series: OutputPathType
    """Un-bandpassed series output"""


def v_3d_rsfc(
    fbot: float,
    ftop: float,
    input_dataset: InputPathType,
    runner: Runner | None = None,
) -> V3dRsfcOutputs:
    """
    Program to calculate common resting state functional connectivity (RSFC)
    parameters.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        fbot: Lowest frequency in the passband, in Hz.
        ftop: Highest frequency in the passband (must be > fbot).
        input_dataset: Input dataset (3D+time sequence of volumes).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRsfcOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RSFC_METADATA)
    cargs = []
    cargs.append("3dRSFC")
    cargs.append("[OPTIONS]")
    cargs.append(str(fbot))
    cargs.append(str(ftop))
    cargs.append(execution.input_file(input_dataset))
    ret = V3dRsfcOutputs(
        root=execution.output_file("."),
        filtered_time_series=execution.output_file("[PREFIX]_LFF+orig.*"),
        un_bandpassed_series=execution.output_file("[PREFIX]_unBP+orig.*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRsfcOutputs",
    "V_3D_RSFC_METADATA",
    "v_3d_rsfc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BIANCA_CLUSTER_STATS_METADATA = Metadata(
    id="7bb9fbd0c4cce5e06e0aa8bae75dec0c569b1f20.boutiques",
    name="bianca_cluster_stats",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class BiancaClusterStatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `bianca_cluster_stats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def bianca_cluster_stats(
    bianca_output_map: InputPathType,
    threshold: float,
    min_cluster_size: float,
    mask: InputPathType | None = None,
    runner: Runner | None = None,
) -> BiancaClusterStatsOutputs:
    """
    Calculate number of clusters and WMH volume in a BIANCA output map.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        bianca_output_map: BIANCA output map file.
        threshold: Threshold value to apply.
        min_cluster_size: Minimum cluster size in voxels.
        mask: Optional mask file (in the same space as the BIANCA output map).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BiancaClusterStatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BIANCA_CLUSTER_STATS_METADATA)
    cargs = []
    cargs.append("bianca_cluster_stats")
    cargs.append(execution.input_file(bianca_output_map))
    cargs.append(str(threshold))
    cargs.append(str(min_cluster_size))
    if mask is not None:
        cargs.append(execution.input_file(mask))
    ret = BiancaClusterStatsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BIANCA_CLUSTER_STATS_METADATA",
    "BiancaClusterStatsOutputs",
    "bianca_cluster_stats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FSLMAT_TO_LTA_METADATA = Metadata(
    id="a584f1ce4737b11d3bc46a9cd0dac5a4276a9a35.boutiques",
    name="mri_fslmat_to_lta",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFslmatToLtaOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fslmat_to_lta(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_lta_file: OutputPathType
    """LTA transformation file created from the given source, target volumes and
    FSL matrix file"""


def mri_fslmat_to_lta(
    src_vol: InputPathType,
    target_vol: InputPathType,
    fslmat_file: InputPathType,
    lta_file: str,
    runner: Runner | None = None,
) -> MriFslmatToLtaOutputs:
    """
    This program creates the LTA transformation file using information from the src
    and target volumes and an FSL matrix file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        src_vol: Source volume file.
        target_vol: Target volume file.
        fslmat_file: FSL transformation matrix file.
        lta_file: Output LTA transformation file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFslmatToLtaOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FSLMAT_TO_LTA_METADATA)
    cargs = []
    cargs.append("mri_fslmat_to_lta")
    cargs.append(execution.input_file(src_vol))
    cargs.append(execution.input_file(target_vol))
    cargs.append(execution.input_file(fslmat_file))
    cargs.append(lta_file)
    ret = MriFslmatToLtaOutputs(
        root=execution.output_file("."),
        output_lta_file=execution.output_file(lta_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FSLMAT_TO_LTA_METADATA",
    "MriFslmatToLtaOutputs",
    "mri_fslmat_to_lta",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MAKE_BEM_SURFACES_METADATA = Metadata(
    id="991d0fd0e24d64260bc9d9bb27cd91c24fb07fb0.boutiques",
    name="mri_make_bem_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMakeBemSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_make_bem_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inner_skull_tri: OutputPathType
    """Generated inner skull surface triangle file."""
    inner_skull_tmp_tri: OutputPathType
    """Temporary file for best guess at inner skull surface."""


def mri_make_bem_surfaces(
    name: str,
    mfile: InputPathType | None = None,
    runner: Runner | None = None,
) -> MriMakeBemSurfacesOutputs:
    """
    Tool to create Boundary Element Method (BEM) surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        name: The name of the subject or session to process.
        mfile: Optional mfile parameter to provide additional settings.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMakeBemSurfacesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MAKE_BEM_SURFACES_METADATA)
    cargs = []
    cargs.append("mri_make_bem_surfaces")
    cargs.append(name)
    if mfile is not None:
        cargs.append(execution.input_file(mfile))
    ret = MriMakeBemSurfacesOutputs(
        root=execution.output_file("."),
        inner_skull_tri=execution.output_file("inner_skull.tri"),
        inner_skull_tmp_tri=execution.output_file("inner_skull_tmp.tri"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MAKE_BEM_SURFACES_METADATA",
    "MriMakeBemSurfacesOutputs",
    "mri_make_bem_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SWAP_SUBJECTWISE_METADATA = Metadata(
    id="bf7096e8cee698d846878d13e1f8e94c40f80ba1.boutiques",
    name="swap_subjectwise",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SwapSubjectwiseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `swap_subjectwise(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def swap_subjectwise(
    dyads: InputPathType,
    fmean: InputPathType,
    mask: InputPathType | None = None,
    obasename: str | None = None,
    xthresh: float | None = None,
    averageonly_flag: bool = False,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> SwapSubjectwiseOutputs:
    """
    Reordering of the dyadic vectors and fsamples according to average inter-subject
    modal orientations.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        dyads: List of list of dyads.
        fmean: List of list of mean fsamples.
        mask: Filename of brain mask.
        obasename: Output obasename [default=swapped].
        xthresh: A.R.D. threshold - default=0.1.
        averageonly_flag: Average only?.
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SwapSubjectwiseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SWAP_SUBJECTWISE_METADATA)
    cargs = []
    cargs.append("swap_subjectwise")
    cargs.extend([
        "-r",
        execution.input_file(dyads)
    ])
    cargs.extend([
        "-f",
        execution.input_file(fmean)
    ])
    if mask is not None:
        cargs.extend([
            "-m",
            execution.input_file(mask)
        ])
    if obasename is not None:
        cargs.extend([
            "-b",
            obasename
        ])
    if xthresh is not None:
        cargs.extend([
            "--xthresh",
            str(xthresh)
        ])
    if averageonly_flag:
        cargs.append("--averageonly")
    if verbose_flag:
        cargs.append("--verbose")
    ret = SwapSubjectwiseOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SWAP_SUBJECTWISE_METADATA",
    "SwapSubjectwiseOutputs",
    "swap_subjectwise",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

TKSURFER_METADATA = Metadata(
    id="603cb4c673862d6704782330c4df67ab125e67dd.boutiques",
    name="tksurfer",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class TksurferOutputs(typing.NamedTuple):
    """
    Output object returned when calling `tksurfer(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def tksurfer(
    subject_id: str,
    hemisphere: str,
    surface_name: str,
    options: str | None = None,
    runner: Runner | None = None,
) -> TksurferOutputs:
    """
    3D visualization tool for cortical surface models (part of FreeSurfer).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_id: Subject identifier.
        hemisphere: Cortical hemisphere (e.g., lh or rh).
        surface_name: Surface name (e.g., inflated, sphere, white).
        options: Optional flags and parameters.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `TksurferOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(TKSURFER_METADATA)
    cargs = []
    cargs.append("tksurfer")
    cargs.append(subject_id)
    cargs.append(hemisphere)
    cargs.append(surface_name)
    if options is not None:
        cargs.append(options)
    ret = TksurferOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "TKSURFER_METADATA",
    "TksurferOutputs",
    "tksurfer",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_LABEL2VOXEL_METADATA = Metadata(
    id="1a0b4441c6daf326201e9ffe4e61b70d47c06809.boutiques",
    name="fsl_label2voxel",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslLabel2voxelOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_label2voxel(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_voxel_data: OutputPathType
    """Output voxel data based on the specified label value"""


def fsl_label2voxel(
    label_value: float,
    labeled_volume: InputPathType,
    src_volume: InputPathType,
    output_filename: str,
    runner: Runner | None = None,
) -> FslLabel2voxelOutputs:
    """
    Converts labeled volumes to voxels based on specified labels.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        label_value: Label value to convert.
        labeled_volume: Labeled volume file.
        src_volume: Source volume file.
        output_filename: Output filename for voxel data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslLabel2voxelOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_LABEL2VOXEL_METADATA)
    cargs = []
    cargs.append("fsl_label2voxel")
    cargs.append(str(label_value))
    cargs.append(execution.input_file(labeled_volume))
    cargs.append(execution.input_file(src_volume))
    cargs.append(output_filename)
    ret = FslLabel2voxelOutputs(
        root=execution.output_file("."),
        output_voxel_data=execution.output_file(output_filename),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_LABEL2VOXEL_METADATA",
    "FslLabel2voxelOutputs",
    "fsl_label2voxel",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SMOOTHEST_METADATA = Metadata(
    id="aa6b4d1f0119965283e907af7439d677cd5d313c.boutiques",
    name="smoothest",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SmoothestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `smoothest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def smoothest(
    mask: InputPathType,
    dof: float | None = None,
    residual_fit_image: InputPathType | None = None,
    zstat_image: InputPathType | None = None,
    verbose_flag: bool = False,
    runner: Runner | None = None,
) -> SmoothestOutputs:
    """
    Tool to estimate smoothness of data from FSL.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        mask: Brain mask volume.
        dof: Number of degrees of freedom.
        residual_fit_image: Filename of `residual-fit` image (use -d).
        zstat_image: Filename of zstat image (not with -d).
        verbose_flag: Switch on diagnostic messages.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SmoothestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SMOOTHEST_METADATA)
    cargs = []
    cargs.append("smoothest")
    if dof is not None:
        cargs.extend([
            "-d",
            str(dof)
        ])
    if residual_fit_image is not None:
        cargs.extend([
            "-r",
            execution.input_file(residual_fit_image)
        ])
    if zstat_image is not None:
        cargs.extend([
            "-z",
            execution.input_file(zstat_image)
        ])
    cargs.extend([
        "-m",
        execution.input_file(mask)
    ])
    if verbose_flag:
        cargs.append("-V")
    ret = SmoothestOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SMOOTHEST_METADATA",
    "SmoothestOutputs",
    "smoothest",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DICOM_TO_RAW_METADATA = Metadata(
    id="7eb027b7c5690d1e6ebc29a721254ed558470f1d.boutiques",
    name="dicom_to_raw",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DicomToRawOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dicom_to_raw(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_raw_file: OutputPathType
    """Output raw file(s)"""


def dicom_to_raw(
    input_dicom: InputPathType,
    runner: Runner | None = None,
) -> DicomToRawOutputs:
    """
    Reads images from DICOM file and writes them to raw file(s).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dicom: Input DICOM file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DicomToRawOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DICOM_TO_RAW_METADATA)
    cargs = []
    cargs.append("dicom_to_raw")
    cargs.append(execution.input_file(input_dicom))
    ret = DicomToRawOutputs(
        root=execution.output_file("."),
        output_raw_file=execution.output_file(pathlib.Path(input_dicom).name + ".raw.0001"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DICOM_TO_RAW_METADATA",
    "DicomToRawOutputs",
    "dicom_to_raw",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FREEVIEW_METADATA = Metadata(
    id="ea7d3ba2300d2eb2c6fc1ff4ec8778d1a042e201.boutiques",
    name="freeview",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FreeviewOutputs(typing.NamedTuple):
    """
    Output object returned when calling `freeview(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def freeview(
    args: str | None = None,
    runner: Runner | None = None,
) -> FreeviewOutputs:
    """
    Freeview is a 3D/2D brain visualization tool.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        args: Arguments for freeview.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FreeviewOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FREEVIEW_METADATA)
    cargs = []
    cargs.append("freeview")
    if args is not None:
        cargs.append(args)
    ret = FreeviewOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FREEVIEW_METADATA",
    "FreeviewOutputs",
    "freeview",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_ROI_AVERAGE_METADATA = Metadata(
    id="1b13bf5892e798c2e102f4545e49286ec743589d.boutiques",
    name="cifti-roi-average",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class CiftiRoiAverageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_roi_average(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def cifti_roi_average(
    cifti_in: InputPathType,
    text_out: str,
    opt_cifti_roi_roi_cifti: InputPathType | None = None,
    opt_left_roi_roi_metric: InputPathType | None = None,
    opt_right_roi_roi_metric: InputPathType | None = None,
    opt_cerebellum_roi_roi_metric: InputPathType | None = None,
    opt_vol_roi_roi_vol: InputPathType | None = None,
    runner: Runner | None = None,
) -> CiftiRoiAverageOutputs:
    """
    Average rows in a single cifti file.
    
    Average the rows that are within the specified ROIs, and write the resulting
    average row to a text file, separated by newlines. If -cifti-roi is
    specified, -left-roi, -right-roi, -cerebellum-roi, and -vol-roi must not be
    specified.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        cifti_in: the cifti file to average rows from.
        text_out: output text file of the average values.
        opt_cifti_roi_roi_cifti: cifti file containing combined rois: the rois\
            as a cifti file.
        opt_left_roi_roi_metric: vertices to use from left hemisphere: the left\
            roi as a metric file.
        opt_right_roi_roi_metric: vertices to use from right hemisphere: the\
            right roi as a metric file.
        opt_cerebellum_roi_roi_metric: vertices to use from cerebellum: the\
            cerebellum roi as a metric file.
        opt_vol_roi_roi_vol: voxels to use: the roi volume file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiRoiAverageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_ROI_AVERAGE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-roi-average")
    cargs.append(execution.input_file(cifti_in))
    cargs.append(text_out)
    if opt_cifti_roi_roi_cifti is not None:
        cargs.extend([
            "-cifti-roi",
            execution.input_file(opt_cifti_roi_roi_cifti)
        ])
    if opt_left_roi_roi_metric is not None:
        cargs.extend([
            "-left-roi",
            execution.input_file(opt_left_roi_roi_metric)
        ])
    if opt_right_roi_roi_metric is not None:
        cargs.extend([
            "-right-roi",
            execution.input_file(opt_right_roi_roi_metric)
        ])
    if opt_cerebellum_roi_roi_metric is not None:
        cargs.extend([
            "-cerebellum-roi",
            execution.input_file(opt_cerebellum_roi_roi_metric)
        ])
    if opt_vol_roi_roi_vol is not None:
        cargs.extend([
            "-vol-roi",
            execution.input_file(opt_vol_roi_roi_vol)
        ])
    ret = CiftiRoiAverageOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_ROI_AVERAGE_METADATA",
    "CiftiRoiAverageOutputs",
    "cifti_roi_average",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MS_REFINE_METADATA = Metadata(
    id="cf2b3ea87eceab7f469060c4f74f2742bb3ca22f.boutiques",
    name="mris_ms_refine",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMsRefineOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_ms_refine(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    white_surface: OutputPathType
    """Generated white matter surface file"""
    pial_surface: OutputPathType
    """Generated gray matter surface file"""
    curvature_file: OutputPathType
    """Curvature file for cortical thickness"""
    layer_iv_surface: OutputPathType
    """Surface file approximating layer IV of the cortical sheet"""


def mris_ms_refine(
    subject_name: str,
    hemisphere: str,
    xform: InputPathType,
    flash_files: list[InputPathType],
    residuals: InputPathType,
    omit_self_intersection: bool = False,
    create_curvature_files: bool = False,
    average_curvature: float | None = 10,
    white_only: bool = False,
    runner: Runner | None = None,
) -> MrisMsRefineOutputs:
    """
    This program positions the tessellation of the cortical surface at the white
    matter surface, then the gray matter surface. It generates surface files for
    these surfaces as well as a 'curvature' file for the cortical thickness, and a
    surface file which approximates layer IV of the cortical sheet.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: The name of the subject.
        hemisphere: The hemisphere to process ('lh' or 'rh').
        xform: The transform file.
        flash_files: Flash images.
        residuals: Residuals file.
        omit_self_intersection: Omit self-intersection and only generate\
            gray/white surface.
        create_curvature_files: Create curvature and area files from white\
            matter surface.
        average_curvature: Average curvature values a specified number of\
            times.
        white_only: Only generate white matter surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMsRefineOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MS_REFINE_METADATA)
    cargs = []
    cargs.append("mris_ms_refine")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    cargs.append(execution.input_file(xform))
    cargs.extend([execution.input_file(f) for f in flash_files])
    cargs.append(execution.input_file(residuals))
    if omit_self_intersection:
        cargs.append("-q")
    if create_curvature_files:
        cargs.append("-c")
    if average_curvature is not None:
        cargs.extend([
            "-a",
            str(average_curvature)
        ])
    if white_only:
        cargs.append("-whiteonly")
    ret = MrisMsRefineOutputs(
        root=execution.output_file("."),
        white_surface=execution.output_file("<subject name>/<hemisphere>.white"),
        pial_surface=execution.output_file("<subject name>/<hemisphere>.pial"),
        curvature_file=execution.output_file("<subject name>/<hemisphere>.curv"),
        layer_iv_surface=execution.output_file("<subject name>/<hemisphere>.layerIV"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MS_REFINE_METADATA",
    "MrisMsRefineOutputs",
    "mris_ms_refine",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMG2STDCOORD_METADATA = Metadata(
    id="1d7099e68b2ebab0fcf6f19fecfa832c5ec7908f.boutiques",
    name="img2stdcoord",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class Img2stdcoordOutputs(typing.NamedTuple):
    """
    Output object returned when calling `img2stdcoord(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def img2stdcoord(
    coordinate_file: str,
    input_image: InputPathType,
    standard_image: InputPathType | None = None,
    affine_transform: InputPathType | None = None,
    warp_field: InputPathType | None = None,
    prewarp_affine_transform: InputPathType | None = None,
    voxel_flag: bool = False,
    mm_flag: bool = False,
    verbose_flag_1: bool = False,
    verbose_flag_2: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> Img2stdcoordOutputs:
    """
    Transforms image coordinates using standard space transformations.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        coordinate_file: Filename containing coordinates. If '-' is used,\
            coordinates are read from standard input.
        input_image: Filename of input image.
        standard_image: Filename of standard image.
        affine_transform: Filename of affine transform (e.g.,\
            example_func2standard.mat).
        warp_field: Filename of warp field (e.g.,\
            highres2standard_warp.nii.gz).
        prewarp_affine_transform: Filename of pre-warp affine transform (e.g.,\
            example_func2highres.mat). Default is identity.
        voxel_flag: Input coordinates in voxels (default).
        mm_flag: Input coordinates in mm.
        verbose_flag_1: Verbose output.
        verbose_flag_2: More verbose output.
        help_flag: Display help message.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Img2stdcoordOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMG2STDCOORD_METADATA)
    cargs = []
    cargs.append("img2stdcoord")
    cargs.append(coordinate_file)
    cargs.extend([
        "-img",
        execution.input_file(input_image)
    ])
    if standard_image is not None:
        cargs.extend([
            "-std",
            execution.input_file(standard_image)
        ])
    if affine_transform is not None:
        cargs.extend([
            "-xfm",
            execution.input_file(affine_transform)
        ])
    if warp_field is not None:
        cargs.extend([
            "-warp",
            execution.input_file(warp_field)
        ])
    if prewarp_affine_transform is not None:
        cargs.extend([
            "-premat",
            execution.input_file(prewarp_affine_transform)
        ])
    if voxel_flag:
        cargs.append("-vox")
    if mm_flag:
        cargs.append("-mm")
    if verbose_flag_1:
        cargs.append("-v")
    if verbose_flag_2:
        cargs.append("-verbose")
    if help_flag:
        cargs.append("-help")
    ret = Img2stdcoordOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMG2STDCOORD_METADATA",
    "Img2stdcoordOutputs",
    "img2stdcoord",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_TOY_PROG_METADATA = Metadata(
    id="1311a81e171aae35dd519b54379bb3bfad692a46.boutiques",
    name="3dToyProg",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dToyProgOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_toy_prog(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v_3d_toy_prog(
    input_dataset: InputPathType,
    output_prefix: str | None = None,
    mask_dataset: InputPathType | None = None,
    output_datum: typing.Literal["float", "short"] | None = None,
    runner: Runner | None = None,
) -> V3dToyProgOutputs:
    """
    A program to illustrate dataset creation and manipulation in C using AFNI's API.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Reference dataset.
        output_prefix: Prefix of the output datasets.
        mask_dataset: Restrict analysis to non-zero voxels in the mask dataset.
        output_datum: Output datum type for one of the datasets. Choose from\
            'float' or 'short'. Default is 'float'.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dToyProgOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_TOY_PROG_METADATA)
    cargs = []
    cargs.append("3dToyProg")
    cargs.extend([
        "-input",
        execution.input_file(input_dataset)
    ])
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    if output_datum is not None:
        cargs.extend([
            "-datum",
            output_datum
        ])
    ret = V3dToyProgOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dToyProgOutputs",
    "V_3D_TOY_PROG_METADATA",
    "v_3d_toy_prog",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

I_MATH_METADATA = Metadata(
    id="82da58a8a784459b76c3083f4eca6f26d139e8c9.boutiques",
    name="iMath",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class IMathOutputs(typing.NamedTuple):
    """
    Output object returned when calling `i_math(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    resulting_image: OutputPathType
    """The output image resulting from the operation."""


def i_math(
    image_dimension: typing.Literal[2, 3, 4],
    output_image: str,
    operations: str,
    image1: InputPathType,
    image2: InputPathType | None = None,
    runner: Runner | None = None,
) -> IMathOutputs:
    """
    iMath is a tool for performing various image mathematical operations on medical
    images, specifically supporting operations on 2D, 3D, and 4D data.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: Dimensionality of the image, either 2, 3, or 4.
        output_image: Path for the output image file.
        operations: Operations to be performed along with parameters, e.g.,\
            GetLargestComponent, MC for Closing, etc.
        image1: First input image file.
        image2: Second input image file, if required by operation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IMathOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(I_MATH_METADATA)
    cargs = []
    cargs.append("iMath")
    cargs.append(str(image_dimension))
    cargs.append(output_image)
    cargs.append(operations)
    cargs.append(execution.input_file(image1))
    if image2 is not None:
        cargs.append(execution.input_file(image2))
    ret = IMathOutputs(
        root=execution.output_file("."),
        resulting_image=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMathOutputs",
    "I_MATH_METADATA",
    "i_math",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DT_RECON_METADATA = Metadata(
    id="2b8457b9d61edcd3ebcd8e361c6c29d3e697032b.boutiques",
    name="dt_recon",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DtReconOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dt_recon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    dwi_nifti: OutputPathType
    """Converted input to NIFTI format."""
    dwi_eddy_corrected: OutputPathType
    """DWI after eddy-current correction."""
    tensor_map: OutputPathType
    """Tensor map."""
    fa_map: OutputPathType
    """Fractional anisotropy (FA) map."""
    fa_tal_map: OutputPathType
    """FA map in Talairach space."""
    register_file_output: OutputPathType
    """Registration file."""
    mask_file: OutputPathType
    """Mask file."""


def dt_recon(
    input_volume: InputPathType,
    subject_id: str,
    output_dir: str,
    bvals_bvecs: str | None = None,
    info_dump: InputPathType | None = None,
    ec_reference: float | None = None,
    no_ec_flag: bool = False,
    no_reg_flag: bool = False,
    register_file: InputPathType | None = None,
    no_tal_flag: bool = False,
    subjects_dir: str | None = None,
    save_ec_residuals_flag: bool = False,
    pca_analysis_flag: bool = False,
    mask_prune_threshold: float | None = None,
    init_spm_flag: bool = False,
    init_fsl_flag: bool = False,
    debug_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> DtReconOutputs:
    """
    Performs DTI reconstruction from the raw DWI input files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume (DWI data).
        subject_id: Subject ID.
        output_dir: Output directory.
        bvals_bvecs: B-values and B-vectors files.
        info_dump: Use info dump created by unpacksdcmdir or dcmunpack.
        ec_reference: Use specified time points as 0-based reference for eddy\
            current correction.
        no_ec_flag: Turn off eddy/motion correction.
        no_reg_flag: Do not register to subject or resample to talairach.
        register_file: Supply a register.lta file instead of registering.
        no_tal_flag: Do not resample FA to talairach space.
        subjects_dir: Specify subjects directory (default env SUBJECTS_DIR).
        save_ec_residuals_flag: Save residual error (dwires and eres).
        pca_analysis_flag: Run PCA/SVD analysis on eres (saves in pca-eres\
            dir).
        mask_prune_threshold: Set threshold for masking (default is FLT_MIN).
        init_spm_flag: Initialize BBR with SPM instead of coreg (requires\
            MATLAB).
        init_fsl_flag: Initialize BBR with FSL instead of coreg.
        debug_flag: Print out lots of info.
        version_flag: Print version of this script and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DtReconOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DT_RECON_METADATA)
    cargs = []
    cargs.append("dt_recon")
    cargs.extend([
        "--i",
        execution.input_file(input_volume)
    ])
    if bvals_bvecs is not None:
        cargs.extend([
            "--b",
            bvals_bvecs
        ])
    cargs.extend([
        "--s",
        subject_id
    ])
    cargs.extend([
        "--o",
        output_dir
    ])
    if info_dump is not None:
        cargs.extend([
            "--info-dump",
            execution.input_file(info_dump)
        ])
    if ec_reference is not None:
        cargs.extend([
            "--ecref",
            str(ec_reference)
        ])
    if no_ec_flag:
        cargs.append("--no-ec")
    if no_reg_flag:
        cargs.append("--no-reg")
    if register_file is not None:
        cargs.extend([
            "--reg",
            execution.input_file(register_file)
        ])
    if no_tal_flag:
        cargs.append("--no-tal")
    if subjects_dir is not None:
        cargs.extend([
            "--sd",
            subjects_dir
        ])
    if save_ec_residuals_flag:
        cargs.append("--eres-save")
    if pca_analysis_flag:
        cargs.append("--pca")
    if mask_prune_threshold is not None:
        cargs.extend([
            "--prune_thr",
            str(mask_prune_threshold)
        ])
    if init_spm_flag:
        cargs.append("--init-spm")
    if init_fsl_flag:
        cargs.append("--init-fsl")
    if debug_flag:
        cargs.append("--debug")
    if version_flag:
        cargs.append("--version")
    ret = DtReconOutputs(
        root=execution.output_file("."),
        dwi_nifti=execution.output_file(output_dir + "/dwi.nii.gz"),
        dwi_eddy_corrected=execution.output_file(output_dir + "/dwi-ec.nii.gz"),
        tensor_map=execution.output_file(output_dir + "/tensor.nii.gz"),
        fa_map=execution.output_file(output_dir + "/fa.nii.gz"),
        fa_tal_map=execution.output_file(output_dir + "/fa-tal.nii.gz"),
        register_file_output=execution.output_file(output_dir + "/register.lta"),
        mask_file=execution.output_file(output_dir + "/mask.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DT_RECON_METADATA",
    "DtReconOutputs",
    "dt_recon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SYNTHMORPH_METADATA = Metadata(
    id="cca34624b81822a73cc5fffde808c9e91f121f25.boutiques",
    name="mri_synthmorph",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSynthmorphOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_synthmorph(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    moved_output_file: OutputPathType | None
    """The registered output image file, resulting from the operation."""
    transform_output_file: OutputPathType
    """Transform file resulting from registration."""


def mri_synthmorph(
    moving_image: InputPathType,
    fixed_image: InputPathType,
    moved_output: InputPathType | None = None,
    transform_output: InputPathType | None = None,
    header_only: bool = False,
    transformation_model: typing.Literal["deform", "affine", "rigid"] | None = "deform",
    init_transform: InputPathType | None = None,
    threads: float | None = None,
    gpu_flag: bool = False,
    smooth: float | None = 1,
    extent: float | None = 256,
    model_weights: InputPathType | None = None,
    inspect_directory: str | None = None,
    runner: Runner | None = None,
) -> MriSynthmorphOutputs:
    """
    SynthMorph is a deep-learning tool for brain-specific MRI image registration
    without preprocessing.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        moving_image: The moving input image, which will be registered to the\
            fixed image.
        fixed_image: The fixed input image, which is used as the reference for\
            registration.
        moved_output: The resulting image after registration.
        transform_output: Output transform file for registration. Can be a text\
            file for linear or an image file for deformable registration.
        header_only: Adjust the voxel-to-world matrix instead of resampling.\
            Linear registration only.
        transformation_model: Specifies the registration transformation model.\
            Options include 'deform', 'affine', and 'rigid'.
        init_transform: Initial linear transform for registration.
        threads: Number of TensorFlow threads to utilize. Defaults to the\
            number of cores.
        gpu_flag: Utilize the GPU specified by CUDA_VISIBLE_DEVICES or GPU 0 if\
            unset or empty.
        smooth: Regularization parameter for deformable registration. Higher\
            values indicate smoother displacement fields.
        extent: Isotropic extent of the registration space in unit voxels.
        model_weights: Alternative model weights as an H5 file.
        inspect_directory: Save model inputs resampled into network space for\
            inspection.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSynthmorphOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SYNTHMORPH_METADATA)
    cargs = []
    cargs.append("mri_synthmorph")
    cargs.append(execution.input_file(moving_image))
    cargs.append(execution.input_file(fixed_image))
    if moved_output is not None:
        cargs.extend([
            "-o",
            execution.input_file(moved_output)
        ])
    if transform_output is not None:
        cargs.extend([
            "-t",
            execution.input_file(transform_output)
        ])
    if header_only:
        cargs.append("-H")
    if transformation_model is not None:
        cargs.extend([
            "-m",
            transformation_model
        ])
    if init_transform is not None:
        cargs.extend([
            "-i",
            execution.input_file(init_transform)
        ])
    if threads is not None:
        cargs.extend([
            "-j",
            str(threads)
        ])
    if gpu_flag:
        cargs.append("-g")
    if smooth is not None:
        cargs.extend([
            "-s",
            str(smooth)
        ])
    if extent is not None:
        cargs.extend([
            "-e",
            str(extent)
        ])
    if model_weights is not None:
        cargs.extend([
            "-w",
            execution.input_file(model_weights)
        ])
    if inspect_directory is not None:
        cargs.extend([
            "--inspect",
            inspect_directory
        ])
    ret = MriSynthmorphOutputs(
        root=execution.output_file("."),
        moved_output_file=execution.output_file(pathlib.Path(moved_output).name) if (moved_output is not None) else None,
        transform_output_file=execution.output_file("[TRANS_OUTPUT]"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SYNTHMORPH_METADATA",
    "MriSynthmorphOutputs",
    "mri_synthmorph",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ABIDS_JSON_INFO_PY_METADATA = Metadata(
    id="29b15b0c3b3b92b7936e8e79bd8f79411f0e65a4.boutiques",
    name="abids_json_info.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AbidsJsonInfoPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `abids_json_info_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def abids_json_info_py(
    json_files: list[InputPathType],
    tr_flag: bool = False,
    te_flag: bool = False,
    te_sec_flag: bool = False,
    match_nii_flag: bool = False,
    field_list: list[str] | None = None,
    list_fields_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> AbidsJsonInfoPyOutputs:
    """
    A tool to extract information from BIDS formatted json files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        json_files: Specify .json file(s).
        tr_flag: Print the TR from the json file in seconds, from the\
            'RepetitionTime' field.
        te_flag: Print out the 'EchoTime' field in milliseconds (the json file\
            stores it in seconds).
        te_sec_flag: Print the 'EchoTime' field in seconds.
        match_nii_flag: Check if there is a .nii or .nii.gz file that matches\
            the .json file (1 if the dataset is loadable).
        field_list: Print any field or list of fields from the json file.
        list_fields_flag: Print a list of the available fields from the .json\
            file. This must be the only argument specified.
        help_flag: Show this help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AbidsJsonInfoPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ABIDS_JSON_INFO_PY_METADATA)
    cargs = []
    cargs.append("abids_json_info.py")
    cargs.extend([execution.input_file(f) for f in json_files])
    if tr_flag:
        cargs.append("-TR")
    if te_flag:
        cargs.append("-TE")
    if te_sec_flag:
        cargs.append("-TE_sec")
    if match_nii_flag:
        cargs.append("-match_nii")
    if field_list is not None:
        cargs.extend([
            "-field",
            *field_list
        ])
    if list_fields_flag:
        cargs.append("-list_fields")
    if help_flag:
        cargs.append("-help")
    ret = AbidsJsonInfoPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ABIDS_JSON_INFO_PY_METADATA",
    "AbidsJsonInfoPyOutputs",
    "abids_json_info_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SCALE_TO_MAP_METADATA = Metadata(
    id="2f7e7a834eba315bf3a7ddf886a5f54b169d9aeb.boutiques",
    name="ScaleToMap",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ScaleToMapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `scale_to_map(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def scale_to_map(
    input_file: InputPathType,
    icol: float,
    vcol: float,
    cmap: str | None = None,
    cmapfile: InputPathType | None = None,
    cmapdb: InputPathType | None = None,
    frf: bool = False,
    clp: list[float] | None = None,
    perc_clp: list[float] | None = None,
    apr: float | None = None,
    anr: float | None = None,
    interp: bool = False,
    nointerp: bool = False,
    direct: bool = False,
    msk_zero: bool = False,
    msk: list[float] | None = None,
    msk_col: list[float] | None = None,
    nomsk_col: bool = False,
    br: float | None = None,
    help_: bool = False,
    verbose: bool = False,
    showmap: bool = False,
    showdb: bool = False,
    novolreg: bool = False,
    noxform: bool = False,
    setenv: str | None = None,
    trace_: bool = False,
    trace_2: bool = False,
    nomall: bool = False,
    yesmall: bool = False,
    runner: Runner | None = None,
) -> ScaleToMapOutputs:
    """
    Tool to scale values to a color map.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_file: Input file in 1D formatted ascii containing node values.
        icol: Index of node index column (-1 if node index is implicit).
        vcol: Index of node value column.
        cmap: Choose one of the standard colormaps available with SUMA.
        cmapfile: Read color map from a Mapfile.
        cmapdb: Read color maps from an AFNI .pal file.
        frf: Indicate that the first row in the file is the first color.
        clp: Clip values in IntVect to specified range.
        perc_clp: Percentile clip values in IntVect to specified range.
        apr: Clip values in IntVect to [0 range].
        anr: Clip values in IntVect to [-range range].
        interp: Use color interpolation between colors in colormap (default).
        nointerp: Turn off color interpolation within the colormap.
        direct: Directly map values to index of color in colormap.
        msk_zero: Mask values that are 0.
        msk: Mask values in vcol between specified range.
        msk_col: Set color of masked voxels.
        nomsk_col: Do not output nodes that got masked.
        br: Apply a brightness factor to colormap and mask color.
        help_: Display help message.
        verbose: Verbose mode.
        showmap: Print colormap to screen and quit.
        showdb: Print colors and colormaps of AFNI along with any loaded from\
            Palfile.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        noxform: Same as -novolreg.
        setenv: Set environment variable ENVname to ENVvalue. Quotes are\
            necessary.
        trace_: Turn on extreme tracing.
        trace_2: Turn on extreme tracing.
        nomall: Turn off memory tracing.
        yesmall: Turn on memory tracing (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ScaleToMapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SCALE_TO_MAP_METADATA)
    cargs = []
    cargs.append("ScaleToMap")
    cargs.append(execution.input_file(input_file))
    cargs.append(str(icol))
    cargs.append(str(vcol))
    if cmap is not None:
        cargs.extend([
            "-cmap",
            cmap
        ])
    if cmapfile is not None:
        cargs.extend([
            "-cmapfile",
            execution.input_file(cmapfile)
        ])
    if cmapdb is not None:
        cargs.extend([
            "-cmapdb",
            execution.input_file(cmapdb)
        ])
    if frf:
        cargs.append("-frf")
    if clp is not None:
        cargs.extend([
            "-clp",
            *map(str, clp)
        ])
    if perc_clp is not None:
        cargs.extend([
            "-perc_clp",
            *map(str, perc_clp)
        ])
    if apr is not None:
        cargs.extend([
            "-apr",
            str(apr)
        ])
    if anr is not None:
        cargs.extend([
            "-anr",
            str(anr)
        ])
    if interp:
        cargs.append("-interp")
    if nointerp:
        cargs.append("-nointerp")
    if direct:
        cargs.append("-direct")
    if msk_zero:
        cargs.append("-msk_zero")
    if msk is not None:
        cargs.extend([
            "-msk",
            *map(str, msk)
        ])
    if msk_col is not None:
        cargs.extend([
            "-msk_col",
            *map(str, msk_col)
        ])
    if nomsk_col:
        cargs.append("-nomsk_col")
    if br is not None:
        cargs.extend([
            "-br",
            str(br)
        ])
    if help_:
        cargs.append("-h")
    if verbose:
        cargs.append("-verb")
    if showmap:
        cargs.append("-showmap")
    if showdb:
        cargs.append("-showdb")
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if setenv is not None:
        cargs.extend([
            "-setenv",
            setenv
        ])
    if trace_:
        cargs.append("-TRACE")
    if trace_2:
        cargs.append("-TRACE")
    if nomall:
        cargs.append("-nomall")
    if yesmall:
        cargs.append("-yesmall")
    ret = ScaleToMapOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SCALE_TO_MAP_METADATA",
    "ScaleToMapOutputs",
    "scale_to_map",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBREGIONS_METADATA = Metadata(
    id="979b0a18dd6ab667938e69e0395fa4e8339bd23a.boutiques",
    name="segment_subregions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubregionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subregions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def segment_subregions(
    structure: str,
    cross: str | None = None,
    long_base: str | None = None,
    sd: str | None = None,
    suffix: str | None = None,
    temp_dir: str | None = None,
    out_dir: str | None = None,
    debug: bool = False,
    threads: float | None = None,
    runner: Runner | None = None,
) -> SegmentSubregionsOutputs:
    """
    Cross-sectional and longitudinal segmentation for brain structures like
    thalamus, brainstem, and hippo-amygdala.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        structure: Structure to segment. Options are: thalamus, brainstem,\
            hippo-amygdala.
        cross: Subject to segment in cross-sectional analysis.
        long_base: Base subject for longitudinal analysis. Timepoints are\
            extracted from the base-tps file.
        sd: Specify subjects directory (will override SUBJECTS_DIR env\
            variable).
        suffix: Optional output file suffix.
        temp_dir: Use alternative temporary directory. This will get deleted\
            unless --debug is enabled.
        out_dir: Use alternative output directory (only for cross-sectional).\
            Default is the subject's `mri` directory.
        debug: Write intermediate debugging outputs.
        threads: Number of threads to use. Defaults to 1.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubregionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBREGIONS_METADATA)
    cargs = []
    cargs.append("segment_subregions")
    cargs.append(structure)
    if cross is not None:
        cargs.extend([
            "--cross",
            cross
        ])
    if long_base is not None:
        cargs.extend([
            "--long-base",
            long_base
        ])
    if sd is not None:
        cargs.extend([
            "--sd",
            sd
        ])
    if suffix is not None:
        cargs.extend([
            "--suffix",
            suffix
        ])
    if temp_dir is not None:
        cargs.extend([
            "--temp-dir",
            temp_dir
        ])
    if out_dir is not None:
        cargs.extend([
            "--out-dir",
            out_dir
        ])
    if debug:
        cargs.append("--debug")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    ret = SegmentSubregionsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBREGIONS_METADATA",
    "SegmentSubregionsOutputs",
    "segment_subregions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__SIMULATE_MOTION_METADATA = Metadata(
    id="5fc17ce508dbb62923e813f5cff61e70e1accb2d.boutiques",
    name="@simulate_motion",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VSimulateMotionOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__simulate_motion(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    simulated_motion_output: OutputPathType | None
    """Motion simulated EPI time series"""


def v__simulate_motion(
    epi: InputPathType,
    motion_file: InputPathType,
    epi_timing: InputPathType | None = None,
    prefix: str | None = None,
    save_workdir: bool = False,
    test: bool = False,
    verb_level: float | None = None,
    vr_base: float | None = None,
    warp_method: str | None = None,
    warp_1_d: InputPathType | None = None,
    warp_master: InputPathType | None = None,
    wsinc5: bool = False,
    help_: bool = False,
    hist: bool = False,
    todo: bool = False,
    ver: bool = False,
    runner: Runner | None = None,
) -> VSimulateMotionOutputs:
    """
    Create simulated motion time series in an EPI dataset based on the provided
    motion parameters and an input volume.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        epi: Input EPI volume or time series (only a volreg base is needed,\
            though more is okay).
        motion_file: Motion parameter file (as output by 3dvolreg).
        epi_timing: Provide EPI dataset with slice timing.
        prefix: Prefix for data results (default = motion_sim.NUM_TRS).
        save_workdir: Do not remove the 'work' directory.
        test: Only test running the program, do not create a simulated motion\
            dataset.
        verb_level: Specify a verbose level (default = 1).
        vr_base: 0-based index of volreg base in EPI dataset.
        warp_method: Specify a method for forward alignment/transform.
        warp_1_d: Specify a 12 parameter affine transformation.
        warp_master: Specify a grid master dataset for the -warp_1D transform.
        wsinc5: Use wsinc5 interpolation in 3dAllineate.
        help_: Show help message.
        hist: Show program modification history.
        todo: Show current todo list.
        ver: Show program version.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VSimulateMotionOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__SIMULATE_MOTION_METADATA)
    cargs = []
    cargs.append("@simulate_motion")
    cargs.extend([
        "-epi",
        execution.input_file(epi)
    ])
    cargs.extend([
        "-motion_file",
        execution.input_file(motion_file)
    ])
    if epi_timing is not None:
        cargs.extend([
            "-epi_timing",
            execution.input_file(epi_timing)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if save_workdir:
        cargs.append("-save_workdir")
    if test:
        cargs.append("-test")
    if verb_level is not None:
        cargs.extend([
            "-verb",
            str(verb_level)
        ])
    if vr_base is not None:
        cargs.extend([
            "-vr_base",
            str(vr_base)
        ])
    if warp_method is not None:
        cargs.extend([
            "-warp_method",
            warp_method
        ])
    if warp_1_d is not None:
        cargs.extend([
            "-warp_1D",
            execution.input_file(warp_1_d)
        ])
    if warp_master is not None:
        cargs.extend([
            "-warp_master",
            execution.input_file(warp_master)
        ])
    if wsinc5:
        cargs.append("-wsinc5")
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if todo:
        cargs.append("-todo")
    if ver:
        cargs.append("-ver")
    ret = VSimulateMotionOutputs(
        root=execution.output_file("."),
        simulated_motion_output=execution.output_file(prefix + "_simulated_motion.nii.gz") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VSimulateMotionOutputs",
    "V__SIMULATE_MOTION_METADATA",
    "v__simulate_motion",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_AUTODET_GWSTATS_METADATA = Metadata(
    id="2408fc8252de26e31ffbcec5b0f37d3113618a46.boutiques",
    name="mris_autodet_gwstats",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisAutodetGwstatsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_autodet_gwstats(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output text file with gray/white statistics"""


def mris_autodet_gwstats(
    output_file: str,
    t1w_volume: InputPathType,
    wm_volume: InputPathType,
    surf: InputPathType,
    subject: str,
    subjects_dir: str,
    lhsurf: InputPathType | None = None,
    rhsurf: InputPathType | None = None,
    min_border_white: float | None = None,
    max_border_white: float | None = None,
    min_gray_at_white_border: float | None = None,
    max_gray: float | None = None,
    max_gray_at_csf_border: float | None = None,
    min_gray_at_csf_border: float | None = None,
    max_csf: float | None = None,
    runner: Runner | None = None,
) -> MrisAutodetGwstatsOutputs:
    """
    Manages the computation of the gray/white statistics used to place the white and
    pial surfaces.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_file: Output text file with stats.
        t1w_volume: T1 weighted volume (usually brain.finalsurfs.mgz).
        wm_volume: White matter volume (usually wm.mgz).
        surf: Surface (usually ?h.orig).
        subject: Subject: reads in brain.finalsurfs.mgz, wm.mgz, lh.orig and\
            rh.orig.
        subjects_dir: SUBJECTS_DIR.
        lhsurf: Left hemisphere surface.
        rhsurf: Right hemisphere surface.
        min_border_white: Minimum border white (MinBW).
        max_border_white: Maximum border white (MaxBW).
        min_gray_at_white_border: Minimum gray at white border (MinGWB).
        max_gray: Maximum gray (MaxG).
        max_gray_at_csf_border: Maximum gray at CSF border (MaxGCSFB).
        min_gray_at_csf_border: Minimum gray at CSF border (MinGCSFB).
        max_csf: Maximum CSF (MaxCSF).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisAutodetGwstatsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_AUTODET_GWSTATS_METADATA)
    cargs = []
    cargs.append("mris_autodet_gwstats")
    cargs.extend([
        "--o",
        output_file
    ])
    cargs.extend([
        "--i",
        execution.input_file(t1w_volume)
    ])
    cargs.extend([
        "--wm",
        execution.input_file(wm_volume)
    ])
    cargs.extend([
        "--surf",
        execution.input_file(surf)
    ])
    if lhsurf is not None:
        cargs.extend([
            "--lh-surf",
            execution.input_file(lhsurf)
        ])
    if rhsurf is not None:
        cargs.extend([
            "--rh-surf",
            execution.input_file(rhsurf)
        ])
    cargs.extend([
        "--s",
        subject
    ])
    cargs.extend([
        "--sd",
        subjects_dir
    ])
    if min_border_white is not None:
        cargs.extend([
            "--min_border_white",
            str(min_border_white)
        ])
    if max_border_white is not None:
        cargs.extend([
            "--max_border_white",
            str(max_border_white)
        ])
    if min_gray_at_white_border is not None:
        cargs.extend([
            "--min_gray_at_white_border",
            str(min_gray_at_white_border)
        ])
    if max_gray is not None:
        cargs.extend([
            "--max_gray",
            str(max_gray)
        ])
    if max_gray_at_csf_border is not None:
        cargs.extend([
            "--max_gray_at_csf_border",
            str(max_gray_at_csf_border)
        ])
    if min_gray_at_csf_border is not None:
        cargs.extend([
            "--min_gray_at_csf_border",
            str(min_gray_at_csf_border)
        ])
    if max_csf is not None:
        cargs.extend([
            "--max_csf",
            str(max_csf)
        ])
    ret = MrisAutodetGwstatsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_AUTODET_GWSTATS_METADATA",
    "MrisAutodetGwstatsOutputs",
    "mris_autodet_gwstats",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MOVE_TO_SERIES_DIRS_METADATA = Metadata(
    id="43e65ff4ccb7c662ae1bcaef0b7fb14c99b76809.boutiques",
    name="@move.to.series.dirs",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMoveToSeriesDirsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__move_to_series_dirs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def v__move_to_series_dirs(
    dicom_files: list[InputPathType],
    action: typing.Literal["copy", "move"] | None = None,
    dprefix: str | None = None,
    tag: str | None = None,
    test: bool = False,
    help_: bool = False,
    hist: bool = False,
    ver: bool = False,
    runner: Runner | None = None,
) -> VMoveToSeriesDirsOutputs:
    """
    Partition DICOM files into series directories by copying or moving them to new
    series directories.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dicom_files: Specify input DICOM files (e.g., IMG*).
        action: Specify action to perform: copy or move. Default is copy.
        dprefix: Specify directory root for output series directories. Default\
            is current directory.
        tag: Specify the DICOM tag to use for partitioning. Default is\
            0020,0011 (REL Series Number).
        test: Run in test mode, only show what would be done without actually\
            moving any files.
        help_: Show help information.
        hist: Show modification history.
        ver: Show version number.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMoveToSeriesDirsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MOVE_TO_SERIES_DIRS_METADATA)
    cargs = []
    cargs.append("@move.to.series.dirs")
    if action is not None:
        cargs.extend([
            "-action",
            action
        ])
    if dprefix is not None:
        cargs.extend([
            "-dprefix",
            dprefix
        ])
    if tag is not None:
        cargs.extend([
            "-tag",
            tag
        ])
    if test:
        cargs.append("-test")
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if ver:
        cargs.append("-ver")
    cargs.extend([execution.input_file(f) for f in dicom_files])
    ret = VMoveToSeriesDirsOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMoveToSeriesDirsOutputs",
    "V__MOVE_TO_SERIES_DIRS_METADATA",
    "v__move_to_series_dirs",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_RPROG_DEMO_METADATA = Metadata(
    id="9ea0856bd790ad5ea87b3e458b8bf8d36950ad92.boutiques",
    name="3dRprogDemo",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRprogDemoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_rprog_demo(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file with the specified prefix."""


def v_3d_rprog_demo(
    input_dsets: list[InputPathType],
    scale: float,
    prefix: str,
    mask: InputPathType | None = None,
    help_aspx: bool = False,
    help_raw: bool = False,
    help_spx: bool = False,
    help_txt: bool = False,
    help_: bool = False,
    show_allowed_options: bool = False,
    verbosity_level: float | None = None,
    runner: Runner | None = None,
) -> V3dRprogDemoOutputs:
    """
    Template program to help users write their own R processing routines on MRI
    volumes.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dsets: Input dataset(s) to be scaled.
        scale: Multiply each voxel by SS.
        prefix: Output prefix (just prefix, no view+suffix needed).
        mask: Process voxels inside this mask only. Default is no masking.
        help_aspx: Display help message with autolabeling.
        help_raw: Display raw help message as in the code.
        help_spx: Display help message in sphinx format.
        help_txt: Display help message in simple text.
        help_: Display help message in simple text.
        show_allowed_options: List of allowed options.
        verbosity_level: Verbosity level. 0 for quiet (Default). 1 or more:\
            talkative.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRprogDemoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_RPROG_DEMO_METADATA)
    cargs = []
    cargs.append("3dRprogDemo")
    cargs.extend([execution.input_file(f) for f in input_dsets])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    cargs.extend([
        "-scale",
        str(scale)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if help_aspx:
        cargs.append("-h_aspx")
    if help_raw:
        cargs.append("-h_raw")
    if help_spx:
        cargs.append("-h_spx")
    if help_txt:
        cargs.append("-h_txt")
    if help_:
        cargs.append("-help")
    if show_allowed_options:
        cargs.append("-show_allowed_options")
    if verbosity_level is not None:
        cargs.extend([
            "-verb",
            str(verbosity_level)
        ])
    ret = V3dRprogDemoOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(prefix + ".nii"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRprogDemoOutputs",
    "V_3D_RPROG_DEMO_METADATA",
    "v_3d_rprog_demo",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_EXVIVO_SURFACES_METADATA = Metadata(
    id="6158a382349b4ec3826fd3779a0f0dfa5790c075.boutiques",
    name="mris_exvivo_surfaces",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisExvivoSurfacesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_exvivo_surfaces(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    white_surface: OutputPathType
    """Generated white matter surface file"""
    gray_surface: OutputPathType
    """Generated gray matter surface file"""
    curvature_file: OutputPathType
    """Curvature file for cortical thickness"""
    layer_iv_surface: OutputPathType
    """Surface file approximating layer IV of the cortical sheet"""


def mris_exvivo_surfaces(
    subject_name: str,
    hemisphere: str,
    omit_self_intersection: bool = False,
    create_curvature_area: bool = False,
    average_curvature: float | None = 10,
    white_only: bool = False,
    formalin: int | None = None,
    runner: Runner | None = None,
) -> MrisExvivoSurfacesOutputs:
    """
    FreeSurfer tool to position tessellation of the cortical surface at the white
    and gray matter surfaces, and generate relevant surface files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_name: Name of the subject.
        hemisphere: Hemisphere (e.g., lh or rh).
        omit_self_intersection: Omit self-intersection check and only generate\
            gray/white surface.
        create_curvature_area: Create curvature and area files from white\
            matter surface.
        average_curvature: Average curvature values a specified number of\
            times.
        white_only: Only generate the white matter surface.
        formalin: Assume hemisphere is in formalin, with provided value\
            indicating presence (0,1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisExvivoSurfacesOutputs`).
    """
    if formalin is not None and not (0 <= formalin <= 1): 
        raise ValueError(f"'formalin' must be between 0 <= x <= 1 but was {formalin}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_EXVIVO_SURFACES_METADATA)
    cargs = []
    cargs.append("mris_exvivo_surfaces")
    cargs.append(subject_name)
    cargs.append(hemisphere)
    if omit_self_intersection:
        cargs.append("-q")
    if create_curvature_area:
        cargs.append("-c")
    if average_curvature is not None:
        cargs.extend([
            "-a",
            str(average_curvature)
        ])
    if white_only:
        cargs.append("-whiteonly")
    if formalin is not None:
        cargs.extend([
            "-formalin",
            str(formalin)
        ])
    ret = MrisExvivoSurfacesOutputs(
        root=execution.output_file("."),
        white_surface=execution.output_file("<subject_name>_<hemisphere>_white"),
        gray_surface=execution.output_file("<subject_name>_<hemisphere>_gray"),
        curvature_file=execution.output_file("<subject_name>_<hemisphere>_curvature"),
        layer_iv_surface=execution.output_file("<subject_name>_<hemisphere>_layerIV"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_EXVIVO_SURFACES_METADATA",
    "MrisExvivoSurfacesOutputs",
    "mris_exvivo_surfaces",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

NSIZE_METADATA = Metadata(
    id="d61eb0714ab51aec00c025a2f54aab55318f6b55.boutiques",
    name="nsize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class NsizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `nsize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    image_out_file: OutputPathType
    """Zero padded output image file"""


def nsize(
    image_in: InputPathType,
    image_out: str,
    runner: Runner | None = None,
) -> NsizeOutputs:
    """
    Zero pads an input image to the nearest larger NxN dimensions.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        image_in: Input image file.
        image_out: Output padded image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `NsizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(NSIZE_METADATA)
    cargs = []
    cargs.append("nsize")
    cargs.append(execution.input_file(image_in))
    cargs.append(image_out)
    ret = NsizeOutputs(
        root=execution.output_file("."),
        image_out_file=execution.output_file(image_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "NSIZE_METADATA",
    "NsizeOutputs",
    "nsize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SPM_T_TO_B_METADATA = Metadata(
    id="aeb4cbf77424f7a4691e003e7bad0ef280a42842.boutiques",
    name="spm_t_to_b",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SpmTToBOutputs(typing.NamedTuple):
    """
    Output object returned when calling `spm_t_to_b(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def spm_t_to_b(
    spm_stem_format: str,
    bshort_stem: str,
    runner: Runner | None = None,
) -> SpmTToBOutputs:
    """
    Converts SPM format to Bshort format.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        spm_stem_format: Input SPM stem format.
        bshort_stem: Output bshort stem.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SpmTToBOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SPM_T_TO_B_METADATA)
    cargs = []
    cargs.append("spm_t_to_b")
    cargs.append(spm_stem_format)
    cargs.append(bshort_stem)
    ret = SpmTToBOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SPM_T_TO_B_METADATA",
    "SpmTToBOutputs",
    "spm_t_to_b",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MORPH_TABLES_RH_METADATA = Metadata(
    id="2f3add04b35d7726ca806ca38014821260043ebc.boutiques",
    name="morph_tables-rh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MorphTablesRhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `morph_tables_rh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def morph_tables_rh(
    options: str | None = None,
    runner: Runner | None = None,
) -> MorphTablesRhOutputs:
    """
    A tool from Freesurfer associated with morphological tables for the right
    hemisphere.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        options: Options used by morph_tables-rh.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MorphTablesRhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MORPH_TABLES_RH_METADATA)
    cargs = []
    if options is not None:
        cargs.extend([
            "-rh",
            "morph_tables" + options
        ])
    ret = MorphTablesRhOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MORPH_TABLES_RH_METADATA",
    "MorphTablesRhOutputs",
    "morph_tables_rh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MCCUTUP_METADATA = Metadata(
    id="3bcabc27a5688982bd8610840860d2e83796bc90.boutiques",
    name="mccutup",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MccutupOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mccutup(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output: OutputPathType | None
    """Output file"""


def mccutup(
    input_: InputPathType,
    output_file: str | None = None,
    param1: str | None = None,
    param2: str | None = None,
    runner: Runner | None = None,
) -> MccutupOutputs:
    """
    FSL mccutup tool.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input_: Input file.
        output_file: Specify output file name.
        param1: Parameter 1 description.
        param2: Parameter 2 description.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MccutupOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MCCUTUP_METADATA)
    cargs = []
    cargs.append("mccutup")
    cargs.append(execution.input_file(input_))
    if output_file is not None:
        cargs.extend([
            "--output",
            output_file
        ])
    if param1 is not None:
        cargs.extend([
            "--param1",
            param1
        ])
    if param2 is not None:
        cargs.extend([
            "--param2",
            param2
        ])
    ret = MccutupOutputs(
        root=execution.output_file("."),
        output=execution.output_file(output_file) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MCCUTUP_METADATA",
    "MccutupOutputs",
    "mccutup",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA = Metadata(
    id="60b32f615cad25bb9b880cab394b4361294d1f30.boutiques",
    name="cifti-create-dense-from-template",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateSeries:
    """
    make a dtseries file instead of a dscalar.
    """
    step: float
    """increment between series points"""
    start: float
    """start value of the series"""
    opt_unit_unit: str | None = None
    """select unit for series (default SECOND): unit identifier"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-series")
        cargs.append(str(self.step))
        cargs.append(str(self.start))
        if self.opt_unit_unit is not None:
            cargs.extend([
                "-unit",
                self.opt_unit_unit
            ])
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateVolumeAll:
    """
    specify an input volume file for all voxel data.
    """
    volume_in: InputPathType
    """the input volume file"""
    opt_from_cropped: bool = False
    """the input is cropped to the size of the voxel data in the template
    file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume-all")
        cargs.append(execution.input_file(self.volume_in))
        if self.opt_from_cropped:
            cargs.append("-from-cropped")
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateCifti:
    """
    use input data from a cifti file.
    """
    cifti_in: InputPathType
    """cifti file containing input data"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-cifti")
        cargs.append(execution.input_file(self.cifti_in))
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateMetric:
    """
    use input data from a metric file.
    """
    structure: str
    """which structure to put the metric file into"""
    metric_in: InputPathType
    """input metric file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-metric")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.metric_in))
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateLabel:
    """
    use input data from surface label files.
    """
    structure: str
    """which structure to put the label file into"""
    label_in: InputPathType
    """input label file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-label")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.label_in))
        return cargs


@dataclasses.dataclass
class CiftiCreateDenseFromTemplateVolume:
    """
    use a volume file for a single volume structure's data.
    """
    structure: str
    """which structure to put the volume file into"""
    volume_in: InputPathType
    """the input volume file"""
    opt_from_cropped: bool = False
    """the input is cropped to the size of the volume structure"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-volume")
        cargs.append(self.structure)
        cargs.append(execution.input_file(self.volume_in))
        if self.opt_from_cropped:
            cargs.append("-from-cropped")
        return cargs


class CiftiCreateDenseFromTemplateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_create_dense_from_template(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_create_dense_from_template(
    template_cifti: InputPathType,
    cifti_out: str,
    series: CiftiCreateDenseFromTemplateSeries | None = None,
    volume_all: CiftiCreateDenseFromTemplateVolumeAll | None = None,
    opt_label_collision_action: str | None = None,
    cifti: list[CiftiCreateDenseFromTemplateCifti] | None = None,
    metric: list[CiftiCreateDenseFromTemplateMetric] | None = None,
    label: list[CiftiCreateDenseFromTemplateLabel] | None = None,
    volume: list[CiftiCreateDenseFromTemplateVolume] | None = None,
    runner: Runner | None = None,
) -> CiftiCreateDenseFromTemplateOutputs:
    """
    Create cifti with matching dense map.
    
    This command helps you make a new dscalar, dtseries, or dlabel cifti file
    that matches the brainordinate space used in another cifti file. The
    template file must have the desired brainordinate space in the mapping along
    the column direction (for dtseries, dscalar, dlabel, and symmetric dconn
    this is always the case). All input cifti files must have a brain models
    mapping along column and use the same volume space and/or surface vertex
    count as the template for structures that they contain. If any input files
    contain label data, then input files with non-label data are not allowed,
    and the -series option may not be used.
    
    Any structure that isn't covered by an input is filled with zeros or the
    unlabeled key.
    
    The <structure> argument of -metric, -label or -volume must be one of the
    following:
    
    CORTEX_LEFT
    CORTEX_RIGHT
    CEREBELLUM
    ACCUMBENS_LEFT
    ACCUMBENS_RIGHT
    ALL_GREY_MATTER
    ALL_WHITE_MATTER
    AMYGDALA_LEFT
    AMYGDALA_RIGHT
    BRAIN_STEM
    CAUDATE_LEFT
    CAUDATE_RIGHT
    CEREBELLAR_WHITE_MATTER_LEFT
    CEREBELLAR_WHITE_MATTER_RIGHT
    CEREBELLUM_LEFT
    CEREBELLUM_RIGHT
    CEREBRAL_WHITE_MATTER_LEFT
    CEREBRAL_WHITE_MATTER_RIGHT
    CORTEX
    DIENCEPHALON_VENTRAL_LEFT
    DIENCEPHALON_VENTRAL_RIGHT
    HIPPOCAMPUS_LEFT
    HIPPOCAMPUS_RIGHT
    INVALID
    OTHER
    OTHER_GREY_MATTER
    OTHER_WHITE_MATTER
    PALLIDUM_LEFT
    PALLIDUM_RIGHT
    PUTAMEN_LEFT
    PUTAMEN_RIGHT
    THALAMUS_LEFT
    THALAMUS_RIGHT
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        template_cifti: file to match brainordinates of.
        cifti_out: the output cifti file.
        series: make a dtseries file instead of a dscalar.
        volume_all: specify an input volume file for all voxel data.
        opt_label_collision_action: how to handle conflicts between label keys:\
            'ERROR', 'SURFACES_FIRST', or 'LEGACY', default 'ERROR', use 'LEGACY'\
            to match v1.4.2 and earlier.
        cifti: use input data from a cifti file.
        metric: use input data from a metric file.
        label: use input data from surface label files.
        volume: use a volume file for a single volume structure's data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiCreateDenseFromTemplateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-create-dense-from-template")
    cargs.append(execution.input_file(template_cifti))
    cargs.append(cifti_out)
    if series is not None:
        cargs.extend(series.run(execution))
    if volume_all is not None:
        cargs.extend(volume_all.run(execution))
    if opt_label_collision_action is not None:
        cargs.extend([
            "-label-collision",
            opt_label_collision_action
        ])
    if cifti is not None:
        cargs.extend([a for c in [s.run(execution) for s in cifti] for a in c])
    if metric is not None:
        cargs.extend([a for c in [s.run(execution) for s in metric] for a in c])
    if label is not None:
        cargs.extend([a for c in [s.run(execution) for s in label] for a in c])
    if volume is not None:
        cargs.extend([a for c in [s.run(execution) for s in volume] for a in c])
    ret = CiftiCreateDenseFromTemplateOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_CREATE_DENSE_FROM_TEMPLATE_METADATA",
    "CiftiCreateDenseFromTemplateCifti",
    "CiftiCreateDenseFromTemplateLabel",
    "CiftiCreateDenseFromTemplateMetric",
    "CiftiCreateDenseFromTemplateOutputs",
    "CiftiCreateDenseFromTemplateSeries",
    "CiftiCreateDenseFromTemplateVolume",
    "CiftiCreateDenseFromTemplateVolumeAll",
    "cifti_create_dense_from_template",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ANALYZE_TRACE_METADATA = Metadata(
    id="3d880a6da4a3639545433e9f6739d09c2df6cf76.boutiques",
    name="AnalyzeTrace",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AnalyzeTraceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `analyze_trace(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def analyze_trace(
    tracefile: InputPathType,
    max_func_lines: int | None = None,
    suma_c: InputPathType | None = None,
    max_err: int | None = None,
    novolreg: bool = False,
    noxform: bool = False,
    setenv: str | None = None,
    trace_: bool = False,
    extreme_trace: bool = False,
    nomall: bool = False,
    yesmall: bool = False,
    runner: Runner | None = None,
) -> AnalyzeTraceOutputs:
    """
    A program to analyze SUMA (and AFNI's perhaps) stack output for functions that
    return with RETURN without bothering to go on the stack.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        tracefile: Trace output file obtained by redirecting the program’s\
            trace output.
        max_func_lines: Set the maximum number of code lines before a function\
            returns. Default is no limit.
        suma_c: FILE is a SUMA_*.c file. It is analyzed for functions that use\
            SUMA_RETURN without ENTRY.
        max_err: Stop after encountering MAX_ERR errors reported in log.\
            Default is 5. Error key terms are: 'Error', 'error', 'corruption'.
        novolreg: Ignore any Rotate, Volreg, Tagalign, or WarpDrive\
            transformations present in the Surface Volume.
        noxform: Same as -novolreg.
        setenv: Set environment variable ENVname to be ENVvalue. Quotes are\
            necessary.
        trace_: Turns on In/Out debug and Memory tracing.
        extreme_trace: Turns on extreme tracing.
        nomall: Turn off memory tracing.
        yesmall: Turn on memory tracing (default).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AnalyzeTraceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ANALYZE_TRACE_METADATA)
    cargs = []
    cargs.append("AnalyzeTrace")
    cargs.append(execution.input_file(tracefile))
    if max_func_lines is not None:
        cargs.extend([
            "-max_func_lines",
            str(max_func_lines)
        ])
    if suma_c is not None:
        cargs.extend([
            "-suma_c",
            execution.input_file(suma_c)
        ])
    if max_err is not None:
        cargs.extend([
            "-max_err",
            str(max_err)
        ])
    if novolreg:
        cargs.append("-novolreg")
    if noxform:
        cargs.append("-noxform")
    if setenv is not None:
        cargs.extend([
            "-setenv",
            setenv
        ])
    if trace_:
        cargs.append("-trace")
    if extreme_trace:
        cargs.append("-TRACE")
    if nomall:
        cargs.append("-nomall")
    if yesmall:
        cargs.append("-yesmall")
    ret = AnalyzeTraceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ANALYZE_TRACE_METADATA",
    "AnalyzeTraceOutputs",
    "analyze_trace",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FEAT2SURF_METADATA = Metadata(
    id="40f6609e9dff7742a78a92c30e97a51a671a1ed7.boutiques",
    name="feat2surf",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Feat2surfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `feat2surf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    lh_output: OutputPathType | None
    """Output statistics on the left hemisphere for the subject"""
    rh_output: OutputPathType | None
    """Output statistics on the right hemisphere for the subject"""
    lh_target_output: OutputPathType | None
    """Output statistics on the left hemisphere for the target subject"""
    rh_target_output: OutputPathType | None
    """Output statistics on the right hemisphere for the target subject"""


def feat2surf(
    feat_dirs: list[str],
    feat_dirfile: InputPathType | None = None,
    proj_frac: float | None = None,
    hemi: str | None = None,
    target: str | None = None,
    surf: str | None = None,
    cope_only: bool = False,
    debug_flag: bool = False,
    nolog_flag: bool = False,
    out_dir: str | None = None,
    runner: Runner | None = None,
) -> Feat2surfOutputs:
    """
    Resamples Feat statistics onto the surface of the subject and onto a
    stereo-taxic surface atlas.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        feat_dirs: Directory where Feat results are stored. Can specify\
            multiple directories.
        feat_dirfile: File with a list of Feat directories.
        proj_frac: Sample functional a fraction of the cortical thickness\
            normal to the surface. Default is 0.
        hemi: Run on specified hemisphere (lh or rh) only. Default is both\
            hemispheres.
        target: Subject used to define common surface space. Default is\
            fsaverage.
        surf: Surface to resample to. Default is white.
        cope_only: Only map the copes and varcopes to the common surface space.
        debug_flag: Turn on debugging.
        nolog_flag: Do not create a log file.
        out_dir: Output directory to use instead of default\
            feat/reg_surf-?h/stats.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Feat2surfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FEAT2SURF_METADATA)
    cargs = []
    cargs.append("feat2surf")
    cargs.extend([
        "--feat",
        *feat_dirs
    ])
    if feat_dirfile is not None:
        cargs.extend([
            "--featdirfile",
            execution.input_file(feat_dirfile)
        ])
    if proj_frac is not None:
        cargs.extend([
            "--projfrac",
            str(proj_frac)
        ])
    if hemi is not None:
        cargs.extend([
            "--hemi",
            hemi
        ])
    if target is not None:
        cargs.extend([
            "--target",
            target
        ])
    if surf is not None:
        cargs.extend([
            "--surf",
            surf
        ])
    if cope_only:
        cargs.append("--cope-only")
    if debug_flag:
        cargs.append("--debug")
    if nolog_flag:
        cargs.append("--nolog")
    if out_dir is not None:
        cargs.extend([
            "--out",
            out_dir
        ])
    ret = Feat2surfOutputs(
        root=execution.output_file("."),
        lh_output=execution.output_file(out_dir + "/reg_surf-lh-Subject/stats") if (out_dir is not None) else None,
        rh_output=execution.output_file(out_dir + "/reg_surf-rh-Subject/stats") if (out_dir is not None) else None,
        lh_target_output=execution.output_file(out_dir + "/reg_surf-lh-targid/stats") if (out_dir is not None) else None,
        rh_target_output=execution.output_file(out_dir + "/reg_surf-rh-targid/stats") if (out_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FEAT2SURF_METADATA",
    "Feat2surfOutputs",
    "feat2surf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMROTATE_METADATA = Metadata(
    id="91ce2622ebf37f0ee8816748397e7f0cf65a832b.boutiques",
    name="imrotate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImrotateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imrotate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """Path to the output image file"""


def imrotate(
    dx: float,
    dy: float,
    phi: float,
    input_image: InputPathType,
    output_image: InputPathType,
    fourier_interpolation: bool = False,
    runner: Runner | None = None,
) -> ImrotateOutputs:
    """
    Shifts and rotates an image.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dx: Pixels to shift rightwards (can be non-integer).
        dy: Pixels to shift downwards (can be non-integer).
        phi: Degrees to rotate clockwise.
        input_image: Input image file.
        output_image: Output image file.
        fourier_interpolation: Use Fourier interpolation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImrotateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMROTATE_METADATA)
    cargs = []
    cargs.append("imrotate")
    if fourier_interpolation:
        cargs.append("-Fourier")
    cargs.append(str(dx))
    cargs.append(str(dy))
    cargs.append(str(phi))
    cargs.append(execution.input_file(input_image))
    cargs.append(execution.input_file(output_image))
    ret = ImrotateOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(pathlib.Path(output_image).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMROTATE_METADATA",
    "ImrotateOutputs",
    "imrotate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

GIFTI_LABEL_ADD_PREFIX_METADATA = Metadata(
    id="3d379a6c755dab747292a0a91f754e423ff73eca.boutiques",
    name="gifti-label-add-prefix",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class GiftiLabelAddPrefixOutputs(typing.NamedTuple):
    """
    Output object returned when calling `gifti_label_add_prefix(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    label_out: OutputPathType
    """the output label file"""


def gifti_label_add_prefix(
    label_in: InputPathType,
    prefix: str,
    label_out: str,
    runner: Runner | None = None,
) -> GiftiLabelAddPrefixOutputs:
    """
    Add prefix to all label names in a gifti label file.
    
    For each label other than '???', prepend <prefix> to the label name.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        label_in: the input label file.
        prefix: the prefix string to add.
        label_out: the output label file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `GiftiLabelAddPrefixOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(GIFTI_LABEL_ADD_PREFIX_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-gifti-label-add-prefix")
    cargs.append(execution.input_file(label_in))
    cargs.append(prefix)
    cargs.append(label_out)
    ret = GiftiLabelAddPrefixOutputs(
        root=execution.output_file("."),
        label_out=execution.output_file(label_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "GIFTI_LABEL_ADD_PREFIX_METADATA",
    "GiftiLabelAddPrefixOutputs",
    "gifti_label_add_prefix",
]
